@@ -652,3 +652,53 @@ get_procs <- function(src) {
 
   return(tbl_data)
 }
+
+#' Perform an OAuth credential exchange to obtain a viewer's OAuth access token.
+#'
+#' @param connect A Connect R6 object.
+#' @param user_session_token The content viewer's session token. This token
+#' can only be obtained when the content is running on a Connect server. The token
+#' identifies the user who is viewing the content interactively on the Connect server.
+#'
+#' Read this value from the HTTP header: `Posit-Connect-User-Session-Token`
+#'
+#' @examples
+#' \dontrun{
+#' library(connectapi)
+#' library(plumber)
+#' client <- connect()
+#'
+#' #* @get /do
+#' function(req){
+#'   user_session_token <- req$HTTP_POSIT_CONNECT_USER_SESSION_TOKEN
+#'   credentials <- get_oauth_credentials(client, user_session_token)
+#'
+#'   # ... do something with `credentials$access_token` ...
+#'
+#'   "done"
+#' }
+#' }
+#'
+#' @return The OAuth credential exchange response.
+#'
+#' @details
+#' Please see https://docs.posit.co/connect/user/oauth-integrations/#obtaining-a-viewer-oauth-access-token
+#' for more information.
+#'
+#' @export
+get_oauth_credentials = function(connect, user_session_token) {
+  validate_R6_class(connect, "Connect")
+  url <- v1_url("oauth", "integrations", "credentials")
+  body <- c(
+    list(
+      grant_type = "urn:ietf:params:oauth:grant-type:token-exchange",
+      subject_token_type = "urn:posit:connect:user-session-token",
+      subject_token = user_session_token
+    )
+  )
+  connect$POST(
+    url,
+    encode = "form",
+    body = body
+  )
+}
