@@ -1,9 +1,3 @@
-context("test user apis")
-
-# should connect with env vars
-test_conn_1 <- connect(prefix = "TEST_1")
-test_conn_2 <- connect(prefix = "TEST_2")
-
 test_that("users_create works", {
   ss <- test_conn_1$server_settings()
   if (ss$authentication$name %in% c("LDAP")) {
