@@ -1,5 +1,3 @@
-context("test printing")
-
 # this (nonstandard) test checks output against a file
 # thus allowing an easy preview of expected output
 # AND some level of standard / consistency / expectation
@@ -8,6 +6,5 @@ context("test printing")
 # writeLines(connectapi:::generate_R6_print_output(), rprojroot::find_testthat_root_file("test-print-output.txt"))
 
 test_that("output matches previous expectation", {
-  local_edition(3)
   expect_snapshot(generate_R6_print_output())
 })
